@@ -7,50 +7,30 @@
 
 #include <QDebug>
 
-#include "config.h"
+#include "phonenumbers/asyoutypeformatter.h"
+#include "phonenumbers/phonenumberutil.h"
 
 DialerUtils::DialerUtils(QObject *parent)
     : QObject(parent)
 {
 }
 
-bool DialerUtils::mute()
+void DialerUtils::fetchSpeakerMode()
 {
-    return m_mute;
-}
-
-bool DialerUtils::speakerMode()
-{
-    return m_speakerMode;
-}
-
-void DialerUtils::setSpeakerMode(bool enabled)
-{
-    if (m_speakerMode != enabled) {
-        m_speakerMode = enabled;
-        Q_EMIT speakerModeChanged(m_speakerMode);
-    }
+    Q_EMIT speakerModeFetched();
 }
 
 void DialerUtils::fetchMute()
 {
-    Q_EMIT muteRequested();
+    Q_EMIT muteFetched();
 }
 
-void DialerUtils::fetchSpeakerMode()
+void DialerUtils::setSpeakerMode(bool enabled)
 {
-    Q_EMIT speakerModeRequested();
+    Q_EMIT speakerModeChanged(enabled);
 }
 
 void DialerUtils::setMute(bool muted)
 {
-    if (m_mute != muted) {
-        m_mute = muted;
-        Q_EMIT muteChanged(m_mute);
-    }
-}
-
-void DialerUtils::syncSettings()
-{
-    Config::self()->load();
+    Q_EMIT muteChanged(muted);
 }
