@@ -14,7 +14,7 @@ class DeclarativeCallUtils : public org::kde::telephony::CallUtils
 public:
     DeclarativeCallUtils(QObject *parent = nullptr);
 
-    Q_INVOKABLE void accept(const QString &deviceUni, const QString &callUni);
+    void fetchCalls();
     Q_INVOKABLE void dial(const QString &deviceUni, const QString &number);
     Q_INVOKABLE QString formatNumber(const QString &number);
     Q_INVOKABLE void hangUp(const QString &deviceUni, const QString &callUni);
